@@ -97,7 +97,15 @@ typedef struct state {
 static te_expr *new_expr(const int type, const te_expr *parameters[]) {
     const int arity = ARITY(type);
     const int psize = sizeof(void*) * arity;
-    const int size = (sizeof(te_expr) - sizeof(void*)) + psize + (IS_CLOSURE(type) ? sizeof(void*) : 0);
+    //const int size = (sizeof(te_expr) - sizeof(void*)) + psize + (IS_CLOSURE(type) ? sizeof(void*) : 0);
+
+    // assert that size is >=  sizeof(te_expr) to fix GCC11 warnings
+    // (modified by Marius Appel on 2021-07-05)
+    int size = (sizeof(te_expr) - sizeof(void*)) + psize + (IS_CLOSURE(type) ? sizeof(void*) : 0);
+    if (size < sizeof(te_expr)) {
+      size = sizeof(te_expr);
+    }
+
     te_expr *ret = malloc(size);
     memset(ret, 0, size);
     if (arity && parameters) {
